

    /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\
    *                                                                 *
    *   DEVIL Screensaver System 1.05                                 *
    *   Copyright  2005 Sebastian Pipping <webmaster@hartwork.org>   *
    *                                                                 *
    *   --> http://www.hartwork.org                                   *
    *                                                                 *
    *                                                                 *
    *   This source code is released under LGPL.                      *
    *   See LGPL.txt for details.                        2005-09-18   *
    *                                                                 *
    \* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */


/*

	-- COMPILE INFO --
	libs:		MSVCRT.LIB kernel32.lib user32.lib gdi32.lib
	threads:	multi-threaded
	opts:		disable all default libs

*/



#include "Devil.h"
#include "DevilConfig.h"

#include <gl/gl.h>
#include <gl/glu.h>
#include <math.h>
#include <time.h>
#include "Winamp/wa_ipc.h"
#include "Winamp/wa_msgids.h"


#define FIRST_TIME_DOWN      0x40000000

#define sqr( X ) ( X * X )
#define PI 3.14159


HDC hdc = NULL;
HGLRC hrc = NULL;


const int iParts = 9;
const int cp = 30;
const double addquot = 8.0;


float angle = 0.0f;

float a1;
float a2;
float a3;

float n1;
float n2;
float n3;


float way_to_go = 0.0f;
const float timefactor = 0.00007f;
const float minus = RAND_MAX / 2.0f;

int iAxisMode = 1;

HWND hWinamp = NULL;



bool FACE_Live();
void FACE_Die();
LRESULT CALLBACK FACE_Master( HWND, UINT, WPARAM, LPARAM );
void FACE_Render( const double );
void FACE_Config( const HWND );
bool FACE_Init3D();
void FACE_Cleanup3D();
bool FACE_SwitchRes( int *, int *, UINT *, UINT * );
void FACE_RestoreRes();



DEVIL_CONFIG g_CONFIG;

DEVIL_INTERFACE g_FACE =
{
	FACE_Live,				// Live
	FACE_Die,				// Die
	FACE_Master,			// Master
	FACE_Render,			// Render
	FACE_Config,			// Config
	FACE_Init3D,			// Init3D
	FACE_Cleanup3D,			// Cleanup3D
	NULL,					// SwitchRes
	NULL,					// RestoreRes
	false,					// bEnableFrameLimiter
	60,						// uMaxFPS
	true,					// bMouseExit
	false,					// bAnyKeyExit

	NULL,					// hwnd
	DEVIL_MODE_UNKNOWN,		// Mode
	NULL,					// Slave
	0.0						// fFPS
};



// ***************************************************************************************
void ReshapeGL (int width, int height)									// Reshape The Window When It's Moved Or Resized
{
	glViewport (0, 0, (GLsizei)(width), (GLsizei)(height));				// Reset The Current Viewport
	glMatrixMode (GL_PROJECTION);										// Select The Projection Matrix
	glLoadIdentity ();													// Reset The Projection Matrix
	gluPerspective (45.0f, (GLfloat)(width)/(GLfloat)(height),			// Calculate The Aspect Ratio Of The Window
					1.0f, 100.0f);
	glMatrixMode (GL_MODELVIEW);										// Select The Modelview Matrix
	glLoadIdentity ();													// Reset The Modelview Matrix
}



// ***************************************************************************************
void ColorPart( int iAll, float fBrightness, float fColor )
{
	const float fSection = fColor / iAll / 2;

	float fRed    = ( float )asin( sin( fSection * PI ) ) * 2 / PI;
	float fGreen  = ( float )fabs( asin( sin( fSection * PI + PI / 3 ) ) * 2 / PI );
	float fBlue   = ( float )fabs( asin( sin( fSection * PI + 2 * PI / 3) ) * 2 / PI );

	const float fMiddle = ( iAll - 1 ) / 2.0f;
	const float fFactor = ( float )( fBrightness - fMiddle ) / fMiddle ;

	if( fBrightness > fMiddle )
	{
		// Brighten
		fRed    += ( 1.0f - fRed   ) * fFactor;
		fGreen  += ( 1.0f - fGreen ) * fFactor;
		fBlue   += ( 1.0f - fBlue  ) * fFactor;
	}
	else
	{
		// Darken
		fRed    += fRed    * fFactor;
		fGreen  += fGreen  * fFactor;
		fBlue   += fBlue   * fFactor;
	}

	glColor3f( fRed, fGreen, fBlue );
}



// ***************************************************************************************
bool FACE_Live()
{
	int res;
	if( g_FACE.Mode == DEVIL_MODE_PREVIEW )
	{
		g_FACE.bEnableFrameLimiter = true;
	}
	else
	{
		g_CONFIG.Read( TEXT( "bEnableFrameLimiter" ), &res, 0 );
		g_FACE.bEnableFrameLimiter = ( bool )res;
	}

	g_CONFIG.Read( TEXT( "iAxisMode" ), &iAxisMode, 1 );
	if( ( iAxisMode > 2 ) || ( iAxisMode < 0 ) ) iAxisMode = 1;

	return true;
}



// ***************************************************************************************
void FACE_Die()
{
	if( g_FACE.Mode == DEVIL_MODE_PREVIEW ) return;

	g_CONFIG.Write( TEXT( "bEnableFrameLimiter" ), ( int )g_FACE.bEnableFrameLimiter );
	g_CONFIG.Write( TEXT( "iAxisMode" ), iAxisMode );
}



// ***************************************************************************************
LRESULT CALLBACK FACE_Master( HWND hwnd, UINT message, WPARAM wp, LPARAM lp )
{
	static bool bInitDone = false;
	
	switch( message )
	{
	case WM_CREATE:
		if( !bInitDone )
		{
			if( g_FACE.Mode == DEVIL_MODE_PREVIEW )
			{
				bInitDone = true;
				break;
			}
			
			// Search running Winamp
			hWinamp = FindWindow( TEXT( "Winamp v1.x" ), NULL );

			bInitDone = true;	
		}
		break;
		
	case WM_KEYDOWN:
		if( g_FACE.Mode == DEVIL_MODE_PREVIEW ) break;

		switch( wp )
		{
		// Toggle axis
		case 'A':
			if( !( lp & FIRST_TIME_DOWN ) )
			{
				iAxisMode++;
				if( iAxisMode > 2 ) iAxisMode = 0;
			}
			break;

		// Toggle frame limiter
		case 'L':
			if( !( lp & FIRST_TIME_DOWN ) )
			{
				g_FACE.bEnableFrameLimiter = !g_FACE.bEnableFrameLimiter;
			}
			break;

		// Play / Restart / Unpause
		case 'X':
		case VK_NUMPAD5:
			if( hWinamp && !( lp & FIRST_TIME_DOWN ) )
			{
				PostMessage( hWinamp, WM_COMMAND, WINAMP_BUTTON2, 0 );
			}
			break;

		// Stop / Stop with fadout / Stop after current track
		case 'V':
			if( hWinamp && !( lp & FIRST_TIME_DOWN ) )
			{
				const bool bShiftDown    = 128 & GetKeyState( VK_SHIFT );
				const bool bControlDown  = 128 & GetKeyState( VK_CONTROL );

				if( bShiftDown == bControlDown )
				{
					// Both or none
					PostMessage( hWinamp, WM_COMMAND, WINAMP_BUTTON4, 0 );
				}
				else
				{
					if( bShiftDown )
						PostMessage( hWinamp, WM_COMMAND, WINAMP_BUTTON4_SHIFT, 0 );
					else
						PostMessage( hWinamp, WM_COMMAND, WINAMP_BUTTON4_CTRL, 0 );
				}
			}
			break;

		// Rause / Unpause
		case 'C':
			if( hWinamp && !( lp & FIRST_TIME_DOWN ) )
			{
				PostMessage( hWinamp, WM_COMMAND, WINAMP_BUTTON3, 0 );
			}
			break;
		
		// Next track
		case 'B':
		case VK_NUMPAD6:
			if( hWinamp && !( lp & FIRST_TIME_DOWN ) )
			{
				PostMessage( hWinamp, WM_COMMAND, WINAMP_BUTTON5, 0 );
			}
			break;

		// Previous track
		case 'Z':
		case 'Y':			// For german keyboards
		case VK_NUMPAD4:
			if( hWinamp && !( lp & FIRST_TIME_DOWN ) )
			{
				PostMessage( hWinamp, WM_COMMAND, WINAMP_BUTTON1, 0 );
			}
			break;

		// Jump ten songs back
		case VK_NUMPAD1:
			if( hWinamp && !( lp & FIRST_TIME_DOWN ) )
			{
				PostMessage( hWinamp, WM_KEYDOWN, wp, lp );
			}
			break;

		// Jump ten songs forward
		case VK_NUMPAD3:
			if( hWinamp && !( lp & FIRST_TIME_DOWN ) )
			{
				PostMessage( hWinamp, WM_KEYDOWN, wp, lp );
			}
			break;

		// Rewind 5 seconds
		case VK_LEFT:
		case VK_NUMPAD7:
			if( hWinamp )
			{
				PostMessage( hWinamp, WM_COMMAND, WINAMP_REW5S, 0 );
			}
			break;

		// Fast-forward 5 seconds
		case VK_RIGHT:
		case VK_NUMPAD9:
			if( hWinamp )
			{
				PostMessage( hWinamp, WM_COMMAND, WINAMP_FFWD5S, 0 );
			}
			break;

		// Turn volume up
		case VK_UP:
		case VK_NUMPAD8:
			if( hWinamp )
			{
				PostMessage( hWinamp, WM_COMMAND, WINAMP_VOLUMEUP, 0 );
			}
			break;

		// Turn volume down
		case VK_DOWN:
		case VK_NUMPAD2:
			if( hWinamp )
			{
				PostMessage( hWinamp, WM_COMMAND, WINAMP_VOLUMEDOWN, 0 );
			}
			break;
		
		}
		break;
		
	}
	return CallWindowProc( g_FACE.Slave, hwnd, message, wp, lp );
}



// ***************************************************************************************
void FACE_Render( const double fPassedTime )
{
	angle += ( float )( fPassedTime / 33.0 );
	if( angle > 360 )
	{
		angle -= 360;
	}

	
	glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );		// Clear Screen And Depth Buffer
	glLoadIdentity();											// Reset The Modelview Matrix
	glTranslatef( 0.0f, 0.0f, -4.0f );							// Translate 4 Units Into The Screen


	float way_right_now = fPassedTime * timefactor;
	if( way_right_now < way_to_go )
	{
		a1 += ( n1 * way_right_now );
		a2 += ( n2 * way_right_now );
		a3 += ( n3 * way_right_now );

		way_to_go -= way_right_now;
	}
	else
	{
		float way_gone_too_much = way_right_now - way_to_go;

		do
		{
			// Old destination
			a1 += ( n1 * way_to_go );
			a2 += ( n2 * way_to_go );
			a3 += ( n3 * way_to_go );

			// New destination
			do
			{
				float f1 = rand() - minus;
				float f2 = rand() - minus;
				float f3 = rand() - minus;

				const float norm_f = sqrt( sqr( f1 ) + sqr( f2 ) + sqr( f3 ) );

				f1 /= norm_f;
				f2 /= norm_f;
				f3 /= norm_f;

				n1 = a1 + f1;
				n2 = a2 + f2;
				n3 = a3 + f3;

				const float new_len = sqrt( sqr( n1 ) + sqr( n2 ) + sqr( n3 ) );

				n1 /= new_len;
				n2 /= new_len;
				n3 /= new_len;

				n1 -= a1;
				n2 -= a2;
				n3 -= a3;

				way_to_go = sqrt( sqr( n1 ) + sqr( n2 ) + sqr( n3 ) );
			} while( ( way_to_go < 0.7f ) && ( way_to_go > 1.6f ) );

			if( way_gone_too_much < way_to_go )
			{
				a1 += n1 * way_gone_too_much;
				a2 += n2 * way_gone_too_much;
				a3 += n3 * way_gone_too_much;

				way_to_go -= way_gone_too_much;

				break;
			}
		}
		while( way_gone_too_much >= 0.01f );
	}

	glRotatef( angle, a1, a2, a3 );


	glBegin( GL_TRIANGLES );								// Begin Drawing Triangles


	// GLOBE
	for( int x = 0; x < iParts * 2; x++ ) //iParts * 2
	{
		const double dAngleX1 = x * PI / iParts;
		const double dAngleX2 = ( x + 1 ) * PI / iParts;

		const double fsinX1 = sin( dAngleX1 );
		const double fsinX2 = sin( dAngleX2 );
		const double fcosX1 = cos( dAngleX1 );
		const double fcosX2 = cos( dAngleX2 );

		// Top
		double dAngleY1 = 0;					// 0 * PI / iParts;	UPPER
		double dAngleY2 = PI / iParts;			// 1 * PI / iParts;	LOWER

		double fsinY1 = 0;						// sin( dAngleY1 )
		double fsinY2 = sin( dAngleY2 );
		double fcosY1 = 1;						// cos( dAngleY1 )
		double fcosY2 = cos( dAngleY2 );


		glColor3f( 0.0f, 0.0f, 0.0f );

		glVertex3f( -fcosX1 * fsinY1, fcosY1, fsinX1 * fsinY1 ); // A
		glVertex3f( -fcosX1 * fsinY2, fcosY2, fsinX1 * fsinY2 ); // B
		glVertex3f( -fcosX2 * fsinY2, fcosY2, fsinX2 * fsinY2 ); // C

		for( int y = 1; y < iParts - 1; y++ )
		{
			dAngleY1 = y * PI / iParts;			// UPPER
			dAngleY2 = ( y + 1 ) * PI / iParts;	// LOWER

			fsinY1 = sin( dAngleY1 );
			fsinY2 = sin( dAngleY2 );
			fcosY1 = cos( dAngleY1 );
			fcosY2 = cos( dAngleY2 );


			// ABC
			double ax = -fcosX2 * fsinY1, ay = fcosY1, az = fsinX2 * fsinY1;
			double bx = -fcosX1 * fsinY1, by = fcosY1, bz = fsinX1 * fsinY1;
			double cx = -fcosX1 * fsinY2, cy = fcosY2, cz = fsinX1 * fsinY2;
			double dx = -fcosX2 * fsinY2, dy = fcosY2, dz = fsinX2 * fsinY2;

			// OIRIGINAL IN BLACK

			glColor4f( 0,0,0,0 );

			// ABC
			glVertex3f( ax, ay, az ); // A
			glVertex3f( bx, by, bz ); // B
			glVertex3f( cx, cy, cz ); // C

			// ACD
			glVertex3f( ax, ay, az ); // A
			glVertex3f( cx, cy, cz ); // C
			glVertex3f( dx, dy, dz ); // D

			ColorPart( iParts, y, x );

			const double mx = (ax+bx+cx+dx)/4.0;
			const double my = (ay+by+cy+dy)/4.0;
			const double mz = (az+bz+cz+dz)/4.0;

			ax += mx/addquot;
			ay += my/addquot;
			az += mz/addquot;

			bx += mx/addquot;
			by += my/addquot;
			bz += mz/addquot;

			cx += mx/addquot;
			cy += my/addquot;
			cz += mz/addquot;

			dx += mx/addquot;
			dy += my/addquot;
			dz += mz/addquot;

			// ABC
			glVertex3f( ax, ay, az ); // A
			glVertex3f( bx, by, bz ); // B
			glVertex3f( cx, cy, cz ); // C

			// ACD
			glVertex3f( ax, ay, az ); // A
			glVertex3f( cx, cy, cz ); // C
			glVertex3f( dx, dy, dz ); // D
		}

		dAngleY1 = ( iParts - 1 ) * PI / iParts;
		dAngleY2 = PI;

		fsinY1 = sin( dAngleY1 );
		fsinY2 = sin( dAngleY2 );
		fcosY1 = cos( dAngleY1 );
		fcosY2 = cos( dAngleY2 );

		glColor4f( 0, 0, 0, 0 );

		glVertex3f( -fcosX2 * fsinY1, fcosY1, fsinX2 * fsinY1 ); // 1
		glVertex3f( -fcosX1 * fsinY1, fcosY1, fsinX1 * fsinY1 ); // 2
		glVertex3f( -fcosX1 * fsinY2, fcosY2, fsinX1 * fsinY2 ); // 3
	}

	glEnd ();											// Done Drawing Triangles


	// Draw axis
	if( iAxisMode )
	{
		const double norma = sqrt( sqr( a1 ) + sqr( a2 ) + sqr( a3 ) ) / 2;
		const double na1 = a1 / norma;
		const double na2 = a2 / norma;
		const double na3 = a3 / norma;
	
		glLoadIdentity ();											// Reset The Modelview Matrix
		glTranslatef( 0.0f, 0.0f, -4.0f );							// Translate 4 Units Into The Screen
	
		const double w = acos( ( 2 * na1 )/( 2 * 2 ) ) * 180 / PI;
		glRotatef ( -w, 0, na3, -na2 );
	
	
		glBegin( GL_LINES );
		
		if( iAxisMode == 1 )
			glColor3f( 1.0f, 1.0f, 1.0f ); // White
		else
			glColor3f( 0.25f, 0.25f, 0.25f ); // Gray
	
		for( int i = 0; i < cp; i++ )
		{
			const double ty1 = sin(i*2*PI/cp)/20;
			const double tz1 = -cos(i*2*PI/cp)/20;
			const double ty0 = sin((i-1)*2*PI/cp)/20;
			const double tz0 = -cos((i-1)*2*PI/cp)/20;

			glVertex3f( -2, ty1, tz1 );
			glVertex3f( 2, ty1, tz1 );
			
			glVertex3f( -2, ty1, tz1 );
			glVertex3f( -2, ty0, tz0 );
			glVertex3f( 2, ty1, tz1 );
			glVertex3f( 2, ty0, tz0 );
		}
		
		glEnd();
	}

	glFlush();							// Flush The GL Rendering Pipeline


	SwapBuffers( hdc );					// Swap Buffers (Double Buffering)
}



// ***************************************************************************************
void FACE_Config( const HWND hParent )
{
	MessageBox(
		hParent,
		TEXT(	"So you don't have to guess the keys...\n"
				"\n"
				"\n"
				"A\t"		"\t"		"Toggle axis mode\n"
				"L\t"		"\t"		"Toggle Frame Limiter\n"
				"\n"
				"\t"		"\t"		"  -- Winamp keys --\n"
				"X\t"		"Num 5\t"	"Play / Restart / Unpause  \n"
				"V\t"		"\t"		"Stop\n"
				"Shift+V\t"	"\t"		"Stop with fadeout\n"
				"Ctrl+V\t"	"\t"		"Stop after current track\n"
				"C\t"		"\t"		"Pause / Unpause\n"
				"B\t"		"Num 6\t"	"Next track\n"
				"Z Y\t"		"Num 4\t"	"Previous track\n"
				"\t"		"Num 1\t"	"Jump 10 songs back\n"
				"\t"		"Num 3\t"	"Jump 10 songs forward\n"
				"Left\t"	"Num 7\t"	"Rewind 5 seconds\n"
				"Right\t"	"Num 9\t"	"Fast-forward 5 seconds\n"
				"Up\t"		"Num 8\t"	"Turn volume up\n"
				"Down\t"	"Num 2\t"	"Turn volume down"
		),
		TEXT( "Pseudoglobe 2" ),
		MB_ICONINFORMATION
	);
}



// ***************************************************************************************
bool FACE_Init3D()
{
	PIXELFORMATDESCRIPTOR pfd =											// pfd Tells Windows How We Want Things To Be
	{
		sizeof( PIXELFORMATDESCRIPTOR ),								// Size Of This Pixel Format Descriptor
		1,																// Version Number
		PFD_DRAW_TO_WINDOW |											// Format Must Support Window
		PFD_SUPPORT_OPENGL |											// Format Must Support OpenGL
		PFD_DOUBLEBUFFER,												// Must Support Double Buffering
		PFD_TYPE_RGBA,													// Request An RGBA Format
		16,																// Select Our Color Depth
		0, 0, 0, 0, 0, 0,												// Color Bits Ignored
		0,																// No Alpha Buffer
		0,																// Shift Bit Ignored
		0,																// No Accumulation Buffer
		0, 0, 0, 0,														// Accumulation Bits Ignored
		16,																// 16Bit Z-Buffer (Depth Buffer)
		0,																// No Stencil Buffer
		0,																// No Auxiliary Buffer
		PFD_MAIN_PLANE,													// Main Drawing Layer
		0,																// Reserved
		0, 0, 0															// Layer Masks Ignored
	};

	RECT windowRect;	// Define Our Window Coordinates
	GetClientRect( g_FACE.hwnd, &windowRect );

	GLuint PixelFormat;													// Will Hold The Selected Pixel Format


	hdc = GetDC (g_FACE.hwnd);											// Grab A Device Context For This Window
	if (hdc == 0)														// Did We Get A Device Context?
	{
		// Failed
		DestroyWindow (g_FACE.hwnd);									// Destroy The Window
		g_FACE.hwnd = 0;												// Zero The Window Handle
		return FALSE;													// Return False
	}

	PixelFormat = ChoosePixelFormat (hdc, &pfd);						// Find A Compatible Pixel Format
	if (PixelFormat == 0)												// Did We Find A Compatible Format?
	{
		// Failed
		ReleaseDC (g_FACE.hwnd, hdc);									// Release Our Device Context
		hdc = 0;														// Zero The Device Context
		DestroyWindow (g_FACE.hwnd);									// Destroy The Window
		g_FACE.hwnd = 0;												// Zero The Window Handle
		return FALSE;													// Return False
	}

	if (SetPixelFormat (hdc, PixelFormat, &pfd) == FALSE)				// Try To Set The Pixel Format
	{
		// Failed
		ReleaseDC (g_FACE.hwnd, hdc);									// Release Our Device Context
		hdc = 0;														// Zero The Device Context
		DestroyWindow (g_FACE.hwnd);									// Destroy The Window
		g_FACE.hwnd = 0;												// Zero The Window Handle
		return FALSE;													// Return False
	}

	hrc = wglCreateContext (hdc);										// Try To Get A Rendering Context
	if (hrc == 0)														// Did We Get A Rendering Context?
	{
		// Failed
		ReleaseDC (g_FACE.hwnd, hdc);									// Release Our Device Context
		hdc = 0;														// Zero The Device Context
		DestroyWindow (g_FACE.hwnd);									// Destroy The Window
		g_FACE.hwnd = 0;												// Zero The Window Handle
		return FALSE;													// Return False
	}

	// Make The Rendering Context Our Current Rendering Context
	if( wglMakeCurrent( hdc, hrc ) == FALSE )
	{
		// Failed
		wglDeleteContext (hrc);											// Delete The Rendering Context
		hrc = 0;														// Zero The Rendering Context
		ReleaseDC (g_FACE.hwnd, hdc);									// Release Our Device Context
		hdc = 0;														// Zero The Device Context
		DestroyWindow (g_FACE.hwnd);									// Destroy The Window
		g_FACE.hwnd = 0;												// Zero The Window Handle
		return FALSE;													// Return False
	}


	ReshapeGL( windowRect.right - windowRect.left, windowRect.bottom - windowRect.top );				// Reshape Our GL Window


	glClearColor( 0.0f, 0.0f, 0.0f, 0.5f );						// Black Background
	glClearDepth( 1.0f );										// Depth Buffer Setup
	glDepthFunc( GL_LEQUAL );									// The Type Of Depth Testing (Less Or Equal)
	glEnable( GL_DEPTH_TEST );									// Enable Depth Testing
	glShadeModel( GL_SMOOTH );									// Select Smooth Shading
	glHint( GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST );		// Set Perspective Calculations To Most Accurate


	// Random gen
	srand( ( unsigned )time( NULL ) );


	// Rotation axis
	a1 = rand() - minus;
	a2 = rand() - minus;
	a3 = rand() - minus;
	const float norm_a = sqrt( sqr( a1 ) + sqr( a2 ) + sqr( a3 ) );
	a1 /= norm_a;
	a2 /= norm_a;
	a3 /= norm_a;


	return true;
}



// ***************************************************************************************
void FACE_Cleanup3D()
{
	if( g_FACE.hwnd != 0 )										// Does The Window Have A Handle?
	{
		if( hdc != 0 )											// Does The Window Have A Device Context?
		{
			wglMakeCurrent( hdc, 0 );							// Set The Current Active Rendering Context To Zero
			if( hrc != 0 )										// Does The Window Have A Rendering Context?
			{
				wglDeleteContext( hrc );						// Release The Rendering Context
				hrc = 0;										// Zero The Rendering Context

			}
			ReleaseDC( g_FACE.hwnd, hdc );						// Release The Device Context
			hdc = 0;											// Zero The Device Context
		}
		DestroyWindow( g_FACE.hwnd );							// Destroy The Window
		g_FACE.hwnd = 0;										// Zero The Window Handle
	}
}


/*
// ***************************************************************************************
bool FACE_SwitchRes( int * x, int * y, UINT * uWidth, UINT * uHeight )
{
	// YOUR CODE HERE

	return true;
}



// ***************************************************************************************
void FACE_RestoreRes()
{
	// YOUR CODE HERE
}
*/
